@@ -1,3 +1,11 @@
+"""
+sentry.wsgi
+~~~~~~~~~~~
+
+:copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
+:license: BSD, see LICENSE for more details.
+"""
+
 #!/usr/bin/env python
 import os, sys, os.path
 
